==> fluxbb-1.4.2p4.tgz: fluxbb/lang/English/admin_index.php <==
<?php

// Language definitions used in admin_index.php
$lang_admin_index = array(

'fopen disabled message'			=>	'Unable to check for upgrade since \'allow_url_fopen\' is disabled on this system.',
'Upgrade check failed message'		=>	'Check for upgrade failed for unknown reasons.',
'Running latest version message'	=>	'You are running the latest version of FluxBB.',
'New version available message'		=>	'A new version of FluxBB has been released. You can download the latest version at %s.',
'PHPinfo disabled message'			=>	'The PHP function phpinfo() has been disabled on this server.',
'Not available'						=>	'Not available',
'Forum admin head'					=>	'Forum administration',
'NA'								=>	'N/A',
'Welcome to admin'					=>	'Welcome to the FluxBB administration control panel. From here you can control vital aspects of the board. Depending on whether you are an administrator or a moderator you can:',
'Welcome 1'							=>	'Organize categories and forums.',
'Welcome 2'							=>	'Set forum-wide options and preferences.',
'Welcome 3'							=>	'Control permissions for users and guests.',
'Welcome 4'							=>	'View IP statistics for users.',
'Welcome 5'							=>	'Ban users.',
'Welcome 6'							=>	'Censor words.',
'Welcome 7'							=>	'Set up user ranks.',
'Welcome 8'							=>	'Prune old posts.',
'Welcome 9'							=>	'Handle post reports.',
'Statistics head'					=>	'Statistics',
'FluxBB version label'				=>	'FluxBB version',
'Check for upgrade'					=>	'Check for upgrade',
'FluxBB version data'				=>	'v%s - %s',
'Server load label'					=>	'Server load',
'Server load data'					=>	'%s - %s user(s) online',
'Environment label'					=>	'Environment',
'Environment data OS'				=>	'Operating system: %s',
'Show info'							=>	'Show info',
'Environment data version'			=>	'PHP: %s - %s',
'Environment data acc'				=>	'Accelerator: %s',
'Turck MMCache'						=>	'Turk MMCache',
'Turck MMCache link'				=>	'turck-mmcache.sourceforge.net',
'ionCube PHP Accelerator'			=>	'ionCube PHP Accelerator',
'ionCube PHP Accelerator link'		=>	'www.php-accelerator.co.uk/',
'Alternative PHP Cache (APC)'		=>	'Alternative PHP Cache (APC)',
'Alternative PHP Cache (APC) link'	=>	'www.php.net/apc/',
'Zend Optimizer'					=>	'Zend Optimizer',
'Zend Optimizer link'				=>	'www.zend.com/products/guard/zend-optimizer',
'eAccelerator'						=>	'eAccelerator',
'eAccelerator link'					=>	'www.eaccelerator.net/',
'XCache'							=>	'XCache',
'XCache link'						=>	'xcache.lighttpd.net/',
'Database label'					=>	'Database',
'Database data rows'				=>	'Rows: %s',
'Database data size'				=>	'Size: %s',

);

==> fluxbb-1.5.0p0.tgz: fluxbb/lang/English/admin_index.php <==
<?php

// Language definitions used in admin_index.php
$lang_admin_index = array(

'fopen disabled message'			=>	'Unable to check for upgrade since \'allow_url_fopen\' is disabled on this system.',
'Upgrade check failed message'		=>	'Check for upgrade failed for unknown reasons.',
'Running latest version message'	=>	'You are running the latest version of FluxBB.',
'New version available message'		=>	'A new version of FluxBB has been released. You can download the latest version at %s.',
'PHPinfo disabled message'			=>	'The PHP function phpinfo() has been disabled on this server.',
'Not available'						=>	'Not available',
'Forum admin head'					=>	'Forum administration',
'NA'								=>	'N/A',
'Welcome to admin'					=>	'Welcome to the FluxBB administration control panel. From here you can control vital aspects of the board. Depending on whether you are an administrator or a moderator you can:',
'Welcome 1'							=>	'Organize categories and forums.',
'Welcome 2'							=>	'Set forum-wide options and preferences.',
'Welcome 3'							=>	'Control permissions for users and guests.',
'Welcome 4'							=>	'View IP statistics for users.',
'Welcome 5'							=>	'Ban users.',
'Welcome 6'							=>	'Censor words.',
'Welcome 7'							=>	'Set up user groups and promotions.',
'Welcome 8'							=>	'Prune old posts.',
'Welcome 9'							=>	'Handle post reports.',
'Statistics head'					=>	'Statistics',
'FluxBB version label'				=>	'FluxBB version',
'Check for upgrade'					=>	'Check for upgrade',
'FluxBB version data'				=>	'v%s - %s',
'Server load label'					=>	'Server load',
'Server load data'					=>	'%s - %s user(s) online',
'Environment label'					=>	'Environment',
'Environment data OS'				=>	'Operating system: %s',
'Show info'							=>	'Show info',
'Environment data version'			=>	'PHP: %s - %s',
'Environment data acc'				=>	'Accelerator: %s',
'Turck MMCache'						=>	'Turck MMCache',
'Turck MMCache link'				=>	'turck-mmcache.sourceforge.net/',
'ionCube PHP Accelerator'			=>	'ionCube PHP Accelerator',
'ionCube PHP Accelerator link'		=>	'www.php-accelerator.co.uk/',
'Alternative PHP Cache (APC)'		=>	'Alternative PHP Cache (APC)',
'Alternative PHP Cache (APC) link'	=>	'www.php.net/apc/',
'Zend Optimizer'					=>	'Zend Optimizer',
'Zend Optimizer link'				=>	'www.zend.com/products/guard/zend-optimizer/',
'eAccelerator'						=>	'eAccelerator',
'eAccelerator link'					=>	'www.eaccelerator.net/',
'XCache'							=>	'XCache',
'XCache link'						=>	'xcache.lighttpd.net/',
'Database label'					=>	'Database',
'Database data rows'				=>	'Rows: %s',
'Database data size'				=>	'Size: %s',

);
